@@ -31,7 +31,9 @@
 #define PCI_DEVICE_ID_NVIDIA_MCP3_AUDIO 0x00da
 #endif
 
-#define DRIVER_VERSION "0.24"
+#ifndef PCI_DEVICE_ID_NVIDIA_CK8S_AUDIO
+#define PCI_DEVICE_ID_NVIDIA_CK8S_AUDIO 0x00ea
+#endif
 
 /* magic numbers to protect our data structures */
 #define NVAUDIO_CARD_MAGIC  0x5072696E /* "Prin" */
@@ -41,13 +43,15 @@
 enum {
     NVIDIA_NFORCE1=0,
     NVIDIA_NFORCE2,
-    NVIDIA_NFORCE3
+    NVIDIA_NFORCE3,
+    NVIDIA_CK8S
 };
 
 static char * card_names[] = {
     "NVIDIA nForce1 Audio",
     "NVIDIA nForce2 Audio",
-    "NVIDIA Hammer Audio"
+    "NVIDIA Hammer Audio",
+    "NVIDIA CK8S Audio"
 };
 
 static struct pci_device_id Nvaudio_pci_tbl [] __initdata = {
@@ -57,6 +61,8 @@ static struct pci_device_id Nvaudio_pci_tbl [] __initdata = {
      PCI_ANY_ID, PCI_ANY_ID, 0, 0, NVIDIA_NFORCE2},
     {PCI_VENDOR_ID_NVIDIA, PCI_DEVICE_ID_NVIDIA_MCP3_AUDIO,
      PCI_ANY_ID, PCI_ANY_ID, 0, 0, NVIDIA_NFORCE3},
+    {PCI_VENDOR_ID_NVIDIA, PCI_DEVICE_ID_NVIDIA_CK8S_AUDIO,
+     PCI_ANY_ID, PCI_ANY_ID, 0, 0, NVIDIA_CK8S},
     {0,}
 };
 
@@ -82,7 +88,9 @@ static int pcmvolleft     = 0;
 static int mastervolright = 0;
 static int pcmvolright    = 0;
 
-/* OSS /dev/mixer file operation methods */
+/**********************************************************************
+* OSS /dev/mixer file operation methods 
+**********************************************************************/
 int Nvaudio_open_mixdev(struct inode *inode, struct file *file)
 {
     int i;
@@ -110,12 +118,15 @@ int Nvaudio_open_mixdev(struct inode *inode, struct file *file)
     return -ENODEV;
 }
 
-/* Function to do all private ioctls calls */
+/**********************************************************************
+* Function to do all private ioctls calls 
+**********************************************************************/
 static int Nvaudio_private_ioctl(struct Nvaudio_card* card, unsigned int cmd, unsigned long arg)
 {
     int ret = 0;
     u32 regIndex = 0;
     u32 regValue = 0;
+    int mute     = 0;
     struct nv_ioctl *nvctl;
     //struct ac97_codec *codec       = card->ac97_codec[0];
 
@@ -170,20 +181,121 @@ static int Nvaudio_private_ioctl(struct Nvaudio_card* card, unsigned int cmd, un
                   ret = -EINVAL;
                break;
             case NV_SET_SPKRSELECT:
-                card->spkrselect = nvctl->val[0];
-                /* set the Global cnt regsiter as well 
+                card->spkrselect = nvctl->val[1];
+                /* set the Global cnt regsiter as well  */
                 Nvaudio_SetSpkrRegister(card);
-                */
                 break;
 
             case NV_GET_SPKRSELECT:
-                nvctl->val[0] = card->spkrselect;
+                nvctl->val[1] = card->spkrselect;
+                if( copy_to_user((void *)arg, nvctl, sizeof(struct nv_ioctl)))
+                  ret = -EINVAL;
                 break;
 
             case NV_SET_ANALOGOUT:
+                ret = Nvaudio_setbusmaster(card,ANALOG_OUT,regValue);
+                break;
+
             case NV_GET_ANALOGOUT:
+                nvctl->val[1] = card->analogstate;
+                if( copy_to_user((void *)arg, nvctl, sizeof(struct nv_ioctl)))
+                  ret = -EINVAL;
+                break;
+
             case NV_SET_DIGITALOUT:
+                if(spdif_status) {
+                    ret = Nvaudio_setbusmaster(card,DIGITAL_OUT,regValue);
+                }else {
+                    ret = -EINVAL;
+                }
+                break;
+
             case NV_GET_DIGITALOUT:
+                nvctl->val[1] = card->digitalstate;
+                if( copy_to_user((void *)arg, nvctl, sizeof(struct nv_ioctl)))
+                  ret = -EINVAL;
+                break;
+
+            case NV_GET_ONOFF:
+                switch(regIndex) {
+                    case SWAP_LINEIN:
+                    case SWAP_MICIN:
+                        nvctl->val[1] = Nvaudio_getswapinfo(card,regIndex);
+                        break;
+                    default:
+                        break;
+                }
+                if( copy_to_user((void *)arg, nvctl, sizeof(struct nv_ioctl)))
+                    ret = -EINVAL;
+
+                break;
+
+            case NV_SET_ONOFF:
+                switch(regIndex) {
+                    case SWAP_LINEIN:
+                    case SWAP_MICIN:
+                        Nvaudio_setswapinfo(card,regIndex,regValue);
+                        break;
+                }
+                break;
+
+            case NV_SET_MICBOOST:
+                mdelay(20); /* wait to register to update */
+                regValue = inw(card->ac97base + AC97_MIC_VOL) & ~(AC97_MICBOOST_MASK);
+                regValue |= (nvctl->val[1] << 6);
+                outw(regValue,card->ac97base + AC97_MIC_VOL); 
+                card->micboost   = nvctl->val[1];
+                break;
+
+            case NV_GET_MICBOOST:
+                regValue      = inw(card->ac97base + AC97_MIC_VOL) & AC97_MICBOOST_MASK;
+                if(card->micboost){
+                    regValue = inw(card->ac97base + AC97_MIC_VOL) | AC97_MICBOOST_MASK;
+                    outw(regValue,card->ac97base + AC97_MIC_VOL); 
+                    regValue   &= AC97_MICBOOST_MASK;
+                }
+                nvctl->val[1] = (regValue >> 6);
+                if( copy_to_user((void *)arg, nvctl, sizeof(struct nv_ioctl)))
+                   ret = -EINVAL;
+                break;
+
+            case NV_SET_PREMIXVOL:
+                // RegIndex check for position
+                if(card->codecType == ADI_CODEC) { 
+                    /* center / lfe seemed swapped */
+                    if(regIndex == PREMIX_CENTER) {
+                        regIndex = PREMIX_SUB;
+                    }else if (regIndex == PREMIX_SUB) {
+                        regIndex = PREMIX_CENTER;
+                    }
+                }
+                regValue = Nvaudio_setpremix_volume(card,regIndex,regValue);
+                break;
+
+            case NV_GET_PREMIXVOL:
+                regValue = Nvaudio_getpremix_volume(card,regIndex,&mute);
+                nvctl->val[0]  = mute;
+                nvctl->val[1]  = regValue;           
+                if( copy_to_user((void *)arg, nvctl, sizeof(struct nv_ioctl)))
+                   ret = -EINVAL;
+                break;
+            
+            case NV_SET_MIXERMUTE:
+                Nvaudio_set_mixermute(card,regIndex,regValue);
+                break;
+
+            case NV_GET_MIXERMUTE:
+                regValue = Nvaudio_get_mixermute(card,regIndex);
+                nvctl->val[1]  = regValue;           
+                if( copy_to_user((void *)arg, nvctl, sizeof(struct nv_ioctl)))
+                   ret = -EINVAL;
+                break;
+
+            case NV_GET_INFO:
+                regValue = Nvaudio_getinfo(card,regIndex,nvctl->name);
+                nvctl->val[1]  = regValue;   
+                if( copy_to_user((void *)arg, nvctl, sizeof(struct nv_ioctl)))
+                   ret = -EINVAL;
                 break;
 
             default:
@@ -200,7 +312,9 @@ static int Nvaudio_private_ioctl(struct Nvaudio_card* card, unsigned int cmd, un
 
 }
 
-/* mixer ioctls */
+/**********************************************************************
+* mixer ioctls 
+**********************************************************************/
 int Nvaudio_ioctl_mixdev(struct inode *inode, struct file *file, unsigned int cmd,
                 unsigned long arg)
 {
@@ -216,6 +330,7 @@ int Nvaudio_ioctl_mixdev(struct inode *inode, struct file *file, unsigned int cm
         get_user(val,(int *)arg);
         switch(i) {
             case SOUND_MIXER_VOLUME: /* Master volume */
+                if(card->mastermute) return ret;
                 mastervolright = (val >> 8) & 0xff;
                 mastervolleft  = val & 0xff;
                 if(mastervolright > 100) mastervolright = 100;
@@ -253,12 +368,16 @@ int Nvaudio_ioctl_mixdev(struct inode *inode, struct file *file, unsigned int cm
 
 struct file_operations Nvaudio_mixer_fops = {
     owner:      THIS_MODULE,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,9)
     llseek:     no_llseek,
+#endif
     ioctl:      Nvaudio_ioctl_mixdev,
     open:       Nvaudio_open_mixdev,
 };
 
-/* Main Interrupt routine */
+/**********************************************************************
+* Main Interrupt routine 
+**********************************************************************/
 static void Nvaudio_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 {
     u32 status = 0;
@@ -305,14 +424,19 @@ static void Nvaudio_interrupt(int irq, void *dev_id, struct pt_regs *regs)
     spin_unlock(&card->lock);
 }
 
-/* AC97 codec initialisation.  These small functions exist so we don't
-   duplicate code between module init and apm resume */
+/**********************************************************************
+* AC97 codec initialisation.  These small functions exist so we don't
+*  duplicate code between module init and apm resume 
+**********************************************************************/
 inline int Nvaudio_ac97_exists(struct Nvaudio_card *card,int ac97_number)
 {
     u32 reg = inl(card->iobase + GLOB_STA);
     return (reg & (0x100 << ac97_number));
 }
 
+/**********************************************************************
+* Nvaudio_ac97_enable_variable_rate
+**********************************************************************/
 inline int Nvaudio_ac97_enable_variable_rate(struct ac97_codec *codec)
 {
     printk("Nvaudio: Nvaudio_ac97_enable_variable_rate \n");
@@ -322,6 +446,9 @@ inline int Nvaudio_ac97_enable_variable_rate(struct ac97_codec *codec)
     return (Nvaudio_ac97_get(codec, AC97_EXTENDED_STATUS)&1);
 }
 
+/**********************************************************************
+* probe & powerup codec
+**********************************************************************/
 int Nvaudio_ac97_probe_and_powerup(struct Nvaudio_card *card,struct ac97_codec *codec)
 {
     /* Returns 0 on failure */
@@ -341,6 +468,7 @@ int Nvaudio_ac97_probe_and_powerup(struct Nvaudio_card *card,struct ac97_codec *
         schedule_timeout(HZ/20);
     }
 
+    card->codecType = REALTEK_CODEC;
     /* Separate Checking for Sigmatel codec. If POWER_CONTROL registers are
        not getting set . check for the id and try to initialize the
        Sigmatel separately.
@@ -355,25 +483,27 @@ int Nvaudio_ac97_probe_and_powerup(struct Nvaudio_card *card,struct ac97_codec *
 
     if((id1 == AC97REG_ADI1885_ID1) && (id2 == AC97REG_ADI1885_ID2))    {
         card->codecType = ADI_CODEC;
-        // set the codec to use the rear surround slots
+        /* set the codec to use the rear surround slots */
         codec->codec_write(codec, AC97_ADI_MULTICHN, 0x7000);
     }
 
     if((i <= 0) && (card->codecsec == SIGMATEL_SECONDARY)){
         i = 10;
-        // set the codec to use enable the clock access register
+        /* set the codec to use enable the clock access register*/
         codec->codec_write(codec, AC97_SIGMATEL_CIC1, 0xABBA);
-        // set the codec to use the BIT_CLK
+        /* set the codec to use the BIT_CLK*/
         codec->codec_write(codec, AC97_SIGMATEL_CIC2, 0x5400);
-        // enable the surround dac
+        /* enable the surround dac*/
         codec->codec_write(codec, AC97_EXTENDED_STATUS, 0x0000);
-        // set the codec to use the rear surround slots
+        /* set the codec to use the rear surround slots */
         codec->codec_write(codec, AC97_SIGMATEL_MULTICHN, 0x0001);
     }
     return i;
 }
 
-/*ac97 bus initialization */
+/**********************************************************************
+* ac97 bus initialization
+**********************************************************************/
 int Nvaudio_ac97_random_init_stuff(struct Nvaudio_card *card)
 {
     int i;
@@ -422,13 +552,15 @@ int Nvaudio_ac97_random_init_stuff(struct Nvaudio_card *card)
     return 0;
 }
 
-/* function to initialize the codec */
+/**********************************************************************
+* function to initialize the codec 
+**********************************************************************/
 int __init Nvaudio_ac97_init(struct Nvaudio_card *card)
 {
     int num_ac97       = 0;
     int total_channels = 0;
-    struct ac97_codec *codec;
-    u16 eid = 0;
+    struct ac97_codec *codec = 0;
+    u16 eid = 0 , easc = 0;
     u32 reg = 0;
 
     card->codecType = 0;
@@ -443,14 +575,13 @@ int __init Nvaudio_ac97_init(struct Nvaudio_card *card)
     /* ICH and ICH0 only support 2 channels so don't bother */
     /* to check....                                         */
 
-    card->channels = 2;
+    card->channels = CHANNEL_STEREO;
     reg = inl(card->iobase + GLOB_STA);
     if ( reg & 0x0200000 )
         card->channels = 6;
     else if ( reg & 0x0100000 )
         card->channels = 4;
     printk(KERN_INFO "Nvaudio: Audio Controller supports %d channels.\n", card->channels);
-    printk(KERN_INFO "NVaudio: Defaulting to base 2 channel mode.\n");
     reg = inl(card->iobase + GLOB_CNT);
     outl(reg & 0xffcfffff, card->iobase + GLOB_CNT);
 
@@ -501,7 +632,7 @@ int __init Nvaudio_ac97_init(struct Nvaudio_card *card)
         /* Don't attempt to get eid until powerup is complete */
         eid = Nvaudio_ac97_get(codec, AC97_EXTENDED_ID);
 
-        if(eid==0xFFFFFF) {
+        if(eid==0xFFFF) {
             printk(KERN_WARNING "Nvaudio: no codec attached ?\n");
             kfree(codec);
             break;
@@ -511,15 +642,16 @@ int __init Nvaudio_ac97_init(struct Nvaudio_card *card)
 
         /* As Spdif support only 48K - restrict the ac97 to play in 48K always*/
         /* added for nvaudio to do spdif support */
-        if(spdif_status)
+        /*if(spdif_status)
             eid &= ~1;
+        */
         card->ac97_features = eid;
 
 #ifdef NV_DEBUG_NORMAL
         printk("Nvaudio: EID  read from  codec %d first\n", eid);
 #endif
         /* Now check the codec for useful features to make up for
-           the dumbness of the 810 hardware engine */
+           the dumbness of the hardware engine */
 
         if(!(eid&0x0001))
             printk(KERN_WARNING "Nvaudio: only 48Khz playback available.\n");
@@ -543,14 +675,7 @@ int __init Nvaudio_ac97_init(struct Nvaudio_card *card)
         /*   - Else check if the codec is revision 2.2        */
         /*     * If surround DACs exist, assign them to slots */
         /*       and increment channel count.                 */
-
-        /* All of this only applies to ICH2 and above. ICH    */
-        /* and ICH0 only support 2 channels.  ICH2 will only  */
-        /* support multiple codecs in a "split audio" config. */
-        /* as described above.                                */
-
-        /* TODO: Remove all the debugging messages!           */
-
+        
         if((eid & 0xc000) == 0) /* primary codec */
             total_channels += 2;
 
@@ -569,7 +694,7 @@ int __init Nvaudio_ac97_init(struct Nvaudio_card *card)
                     total_channels += 2;
                 printk("Nvaudio: AC'97 codec %d supports AMAP, total channels = %d\n", num_ac97, total_channels);
 
-            } else if (eid & 0x0400) {  /* this only works on 2.2 compliant codecs */
+            } else if (card->codecType != ADI_CODEC) {  
                 eid &= 0xffcf;
                 if((eid & 0xc000) != 0) {
                     switch ( total_channels ) {
@@ -590,15 +715,22 @@ int __init Nvaudio_ac97_init(struct Nvaudio_card *card)
                 }
                 Nvaudio_ac97_set(codec, AC97_EXTENDED_ID, eid);
                 eid = Nvaudio_ac97_get(codec, AC97_EXTENDED_ID);
-                if (eid & 0x0080) /* L/R Surround channels */
+                if (eid & 0x0080) /* L/R Surround channels */ {
                     total_channels += 2;
-                if (eid & 0x0140) /* LFE and Center channels */
+                    /* clear register 2a bit 12 */
+                    easc = Nvaudio_ac97_get(codec,AC97_EXTENDED_STATUS);
+                    easc &= 0xcfff;
+                    Nvaudio_ac97_set(codec,AC97_EXTENDED_STATUS,easc);
+                }
+                if (eid & 0x0140) /* LFE and Center channels */ {
                     total_channels += 2;
+                    /* clear register 2a bit 11 & 13 */
+                    easc = Nvaudio_ac97_get(codec,AC97_EXTENDED_STATUS);
+                    easc &= 0xb7ff;
+                    Nvaudio_ac97_set(codec,AC97_EXTENDED_STATUS,easc);
+                }
                 printk("Nvaudio: AC'97 codec %d, DAC map configured, total channels = %d\n", num_ac97, total_channels);
-            } else {
-                if(card->codecType != ADI_CODEC)
-                    printk("Nvaudio: AC'97 codec %d Unable to map surround DAC's (or DAC's not present), total channels = %d\n", num_ac97, total_channels);
-            }
+            } 
         }
         if ((codec->dev_mixer = register_sound_mixer(&Nvaudio_mixer_fops, -1)) < 0) {
             printk(KERN_ERR "Nvaudio: couldn't register mixer!\n");
@@ -607,6 +739,9 @@ int __init Nvaudio_ac97_init(struct Nvaudio_card *card)
         }
 
         card->ac97_codec[num_ac97] = codec;
+        card->analogstate          = TRUE;
+        card->digitalstate         = TRUE;
+
 
         if(card->codecsec == NO_SECONDARY) {
             /* Get the master vol and pcmvol for spdif - need to take separate for multiple codec */
@@ -627,21 +762,40 @@ int __init Nvaudio_ac97_init(struct Nvaudio_card *card)
             num_ac97       += 1;
             break;
         }
+
     }
 
+    /*Allocate the List for Output buffer */
+    if(!card->outList) {
+        card->outList = (listPtr) kmalloc(sizeof(struct LList), GFP_KERNEL);
+        if(card->outList == NULL) {
+            printk(KERN_ERR " Failed to allocate the outbuffer Linked List \n");
+            return -ENOMEM;
+        }
+        memset(card->outList,0,sizeof(struct LList));
+    }
     /* pick the minimum of channels supported by ICHx or codec(s) */
     card->channels = (card->channels > total_channels)?total_channels:card->channels;
-
+    /* set the volume registers to maximum*/
+    if((card->channels == 6) && (card->codecType == REALTEK_CODEC)) {
+        if(codec) {
+            Nvaudio_ac97_set(codec,AC97_SURROUND_MASTER,0);
+            Nvaudio_ac97_set(codec,AC97_CENTER_LFE_MASTER,0);
+        }
+    }
     return num_ac97;
 }
 
+/**********************************************************************
+* function to configure clocks
+**********************************************************************/
 void __init Nvaudio_configure_clocking (void)
 {
-    struct Nvaudio_card   *card;
-    struct Nvaudio_state  *state;
+    struct Nvaudio_card   *card  = NULL;
+    struct Nvaudio_state  *state = NULL;
     struct dmabuf *dmabuf;
     unsigned int i, offset, new_offset;
-    unsigned long flags;
+    unsigned long flags = 0;
 
     card = devs;
     /* We could try to set the clocking for multiple cards, but can you even have
@@ -651,7 +805,7 @@ void __init Nvaudio_configure_clocking (void)
      * is a waste of time.
      */
     if(card != NULL) {
-        state = card->wavout = (struct Nvaudio_state*)
+        state =  (struct Nvaudio_state *)
                     kmalloc(sizeof(struct Nvaudio_state), GFP_KERNEL);
 
         if (state == NULL)
@@ -665,11 +819,12 @@ void __init Nvaudio_configure_clocking (void)
 #endif
 
         state->card    = card;
+        card->wavout   = state;
+        spin_lock_init(&state->lock);
         init_waitqueue_head(&dmabuf->wait);
         state->fmt     = NVAUDIO_FMT_STEREO | NVAUDIO_FMT_16BIT;
         state->trigger = PCM_ENABLE_OUTPUT;
         Nvaudio_set_dac_rate(state, 48000);
-
         if(prog_dmabuf(state,0) != 0) {
             goto config_out_nodmabuf;
         }
@@ -701,6 +856,7 @@ void __init Nvaudio_configure_clocking (void)
             clocking = clocking * clocking / i;
             printk("Nvaudio: setting clocking to %d\n", clocking);
         }
+        card->mastermute = 0;
 config_out:
         dealloc_dmabuf(state);
 config_out_nodmabuf:
@@ -709,8 +865,11 @@ config_out_nodmabuf:
     }
 }
 
-/* install the driver, we do not allocate hardware channel nor DMA buffer now, they are defered
-   until "ACCESS" time (in prog_dmabuf called by open/read/write/ioctl/mmap) */
+/**********************************************************************
+* install the driver, we do not allocate hardware channel nor DMA buffer now, 
+* they are defered until "ACCESS" time 
+* (in prog_dmabuf called by open/read/write/ioctl/mmap) 
+**********************************************************************/
 int __init Nvaudio_probe(struct pci_dev *pci_dev, const struct pci_device_id *pci_id)
 {
 #ifdef ENABLE_SPDIF
@@ -732,6 +891,7 @@ int __init Nvaudio_probe(struct pci_dev *pci_dev, const struct pci_device_id *pc
         return -ENOMEM;
     }
     memset(card, 0, sizeof(*card));
+    spin_lock_init(&card->lock);
 
     card->initializing = 1;
     card->iobase       = pci_resource_start (pci_dev, 1);
@@ -801,6 +961,7 @@ int __init Nvaudio_probe(struct pci_dev *pci_dev, const struct pci_device_id *pc
     card->initializing = 0;
     /* set the Spkr as Stereo by default*/
     card->spkrselect  = NV_SPKR_STEREO;
+    card->curspkr     = card->spkrselect;
     return 0;
 
 out_pio:
@@ -815,6 +976,9 @@ out_mem:
 
 }
 
+/**********************************************************************
+* function to remove the device
+**********************************************************************/
 void __devexit Nvaudio_remove(struct pci_dev *pci_dev)
 {
     int i;
@@ -826,6 +990,14 @@ void __devexit Nvaudio_remove(struct pci_dev *pci_dev)
     regvalue = (regvalue & 0xFEFFFFFF);
     pci_write_config_dword(pci_dev,0x4C,regvalue);
 
+    if(card->outList){
+        /* delete any node if present */
+        while(card->outList->nodecount){
+            Nvaudio_deletenode(card);
+        }
+        kfree(card->outList);
+        card->outList = NULL;
+    }
     /* free hardware resources */
     free_irq(card->irq, devs);
     release_region(card->iobase, 64);
@@ -846,6 +1018,9 @@ void __devexit Nvaudio_remove(struct pci_dev *pci_dev)
 
 }
 
+/**********************************************************************
+* function to pm suspend
+**********************************************************************/
 #ifdef CONFIG_PM
 int Nvaudio_pm_suspend(struct pci_dev *dev, u32 pm_state)
 {
@@ -926,7 +1101,10 @@ int Nvaudio_pm_suspend(struct pci_dev *dev, u32 pm_state)
     return 0;
 }
 
-/* Function that retains the hardware registers when coming from sleep mode */
+/**********************************************************************
+* function to pm resume
+* Function that retains the hardware registers when coming from sleep mode
+**********************************************************************/
 int Nvaudio_pm_resume(struct pci_dev *dev)
 {
     int num_ac97,i=0;
@@ -1014,9 +1192,10 @@ int Nvaudio_pm_resume(struct pci_dev *dev)
 
 MODULE_AUTHOR("");
 MODULE_DESCRIPTION("Nvidia audio support");
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,9)
 MODULE_LICENSE("GPL");
+#endif
 MODULE_PARM(clocking, "i");
-MODULE_PARM(strict_clocking, "i");
 MODULE_PARM(spdif_status, "i");
 
 static struct pci_driver Nvaudio_pci_driver = {
@@ -1030,14 +1209,16 @@ static struct pci_driver Nvaudio_pci_driver = {
 #endif /* CONFIG_PM */
 };
 
-/* init module function */
+/**********************************************************************
+* init module function
+**********************************************************************/
 int __init Nvaudio_init_module (void)
 {
     if (!pci_present())   /* No PCI bus in this machine! */
         return -ENODEV;
 
-    printk(KERN_INFO "Nvidia + AC97 Audio, version "
-           DRIVER_VERSION ", " __TIME__ " " __DATE__ "\n");
+    printk(KERN_INFO "Nvidia Audio, " __TIME__ " " __DATE__ " version %s \n",
+           DRIVERVER);
 
     printk("Nvaudio: in Funcction Nvaudio_init_module \n");
     if (!pci_register_driver(&Nvaudio_pci_driver)) {
@@ -1047,7 +1228,9 @@ int __init Nvaudio_init_module (void)
     return 0;
 }
 
-/* Module clean function*/
+/**********************************************************************
+* Module clean function
+**********************************************************************/
 void __exit Nvaudio_cleanup_module (void)
 {
     pci_unregister_driver(&Nvaudio_pci_driver);
